ImgixStringOpts extension

ImgixStringOpts provides simplified syntax for checking and converting string.

on

Properties

hasBase64Padding bool

Available on String, provided by the ImgixStringOpts extension

hasBase64Padding checks if the paramKey is suffixed by "=.
no setter
inBase64Encoding String

Available on String, provided by the ImgixStringOpts extension

inBase64Encoding converts string into base 64 encoded format without padding any character "=".
no setter
inUriEncodeComponent String

Available on String, provided by the ImgixStringOpts extension

inUriEncodedComponent converts String into safe uri path component
no setter
isAsciiHTTPProxy bool

Available on String, provided by the ImgixStringOpts extension

no setter
isBase64 bool

Available on String, provided by the ImgixStringOpts extension

isBase64 checks if the paramKey is suffixed by "64," indicating that the value is intended to be base64-URL-encoded.
no setter
isEncodedHTTPProxy bool

Available on String, provided by the ImgixStringOpts extension

no setter
sanitizedPath String

Available on String, provided by the ImgixStringOpts extension

no setter
unpad String

Available on String, provided by the ImgixStringOpts extension

unpad remove all base64 padding characters.
no setter

Methods

encodeProxy() String

Available on String, provided by the ImgixStringOpts extension